package com.bonus.canteen.core.account.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.account.domain.param.AccConsumeDetailQueryParam;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.account.domain.AccTrade;
import com.bonus.canteen.core.account.service.IAccTradeService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 账户交易记录Controller
 * 
 * @author xsheng
 * @date 2025-04-05
 */
@Api(tags = "账户交易记录接口")
@RestController
@RequestMapping("/acc_trade")
public class AccTradeController extends BaseController {
    @Autowired
    private IAccTradeService accTradeService;

    /**
     * 查询账户交易记录列表
     */
    @ApiOperation(value = "查询账户交易记录列表")
    //@RequiresPermissions("account:trade:list")
    @GetMapping("/list")
    public TableDataInfo list(AccTrade accTrade) {
        startPage();
        List<AccTrade> list = accTradeService.selectAccTradeList(accTrade);
        return getDataTable(list);
    }

    /**
     * 导出账户交易记录列表
     */
    @ApiOperation(value = "导出账户交易记录列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("account:trade:export")
    @SysLog(title = "账户交易记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出账户交易记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, AccTrade accTrade) {
        List<AccTrade> list = accTradeService.selectAccTradeList(accTrade);
        ExcelUtil<AccTrade> util = new ExcelUtil<AccTrade>(AccTrade.class);
        util.exportExcel(response, list, "账户交易记录数据");
    }

    /**
     * 获取账户交易记录详细信息
     */
    @ApiOperation(value = "获取账户交易记录详细信息")
    //@RequiresPermissions("account:trade:query")
    @GetMapping(value = "/{tradeId}")
    public AjaxResult getInfo(@PathVariable("tradeId") Long tradeId) {
        return success(accTradeService.selectAccTradeByTradeId(tradeId));
    }

    /**
     * 新增账户交易记录
     */
    @ApiOperation(value = "新增账户交易记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("account:trade:add")
    @SysLog(title = "账户交易记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增账户交易记录")
    @PostMapping
    public AjaxResult add(@RequestBody AccTrade accTrade) {
        try {
            return toAjax(accTradeService.insertAccTrade(accTrade));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改账户交易记录
     */
    @ApiOperation(value = "修改账户交易记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("account:trade:edit")
    @SysLog(title = "账户交易记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改账户交易记录")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody AccTrade accTrade) {
        try {
            return toAjax(accTradeService.updateAccTrade(accTrade));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除账户交易记录
     */
    @ApiOperation(value = "删除账户交易记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("account:trade:remove")
    @SysLog(title = "账户交易记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除账户交易记录")
	@PostMapping("/del/{tradeIds}")
    public AjaxResult remove(@PathVariable Long[] tradeIds) {
        return toAjax(accTradeService.deleteAccTradeByTradeIds(tradeIds));
    }

    /**
     * 账户消费记录
     */
    @ApiOperation(value = "账户消费记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("account:trade:remove")
    @SysLog(title = "账户消费记录", businessType = OperaType.QUERY, logType = 1,module = "账户->账户消费记录")
    @PostMapping("/consume/detail")
    public TableDataInfo consumeDetail(@RequestBody AccConsumeDetailQueryParam param) {
        startPage();
        return getDataTable(accTradeService.queryAccConsumeDetail(param));
    }
}
